aboutsummaryrefslogtreecommitdiff
path: root/examples/genotype.scm
diff options
context:
space:
mode:
authorMunyoki Kilyungi2023-08-21 15:03:20 +0300
committerMunyoki Kilyungi2023-08-21 15:06:06 +0300
commit8e1e4cceab516afab46ccced63ca9edab663ca11 (patch)
treecad625c3ecf0a555d7b56b777cdade535cb30d07 /examples/genotype.scm
parent51b3c0548c98e0bc05e11a89cbf6b75d31b9f8d5 (diff)
downloadgn-transform-databases-8e1e4cceab516afab46ccced63ca9edab663ca11.tar.gz
Rename dump -> transform
Signed-off-by: Munyoki Kilyungi <me@bonfacemunyoki.com>
Diffstat (limited to 'examples/genotype.scm')
-rwxr-xr-xexamples/genotype.scm10
1 files changed, 5 insertions, 5 deletions
diff --git a/examples/genotype.scm b/examples/genotype.scm
index 63b85a7..6fe60c9 100755
--- a/examples/genotype.scm
+++ b/examples/genotype.scm
@@ -7,10 +7,10 @@
(srfi srfi-26)
(ice-9 match)
(ice-9 regex)
- (dump strings)
- (dump sql)
- (dump triples)
- (dump special-forms))
+ (transform strings)
+ (transform sql)
+ (transform triples)
+ (transform special-forms))
@@ -86,7 +86,7 @@
'^^xsd:double))
(set gnt:hasSequence (field Geno Sequence))
(set gnt:hasSource (field Geno Source))
;; Only dump Source2 if it differs from Source
(set gnt:hasAltSourceName
(field ("IF((Source2 = Source), NULL, Source2)"
Source2)))
@@ -86,7 +86,7 @@
(set gnt:hasSequence (field Geno Sequence))
(set gnt:hasSource (field Geno Source))
- ;; Only dump Source2 if it differs from Source
+ ;; Only transform Source2 if it differs from Source
(set gnt:hasAltSourceName
(field ("IF((Source2 = Source), NULL, Source2)"